@@ -288,7 +288,7 @@ public class CalDAVOnboardingProvider implements OnboardingPlistProvider {
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
         if (null == property || !property.isDefined()) {
             if (generateIfAbsent) {
-                return OnboardingUtility.constructURLWithParameters(hostData, null, "/caldav", false, null).toString();
+                return OnboardingUtility.constructURLWithParameters(hostData, null, "/caldav", null).toString();
             }
             throw OnboardingExceptionCodes.MISSING_PROPERTY.create(propertyName);
         }
@@ -296,7 +296,7 @@ public class CalDAVOnboardingProvider implements OnboardingPlistProvider {
         String value = property.get();
         if (Strings.isEmpty(value)) {
             if (generateIfAbsent) {
-                return OnboardingUtility.constructURLWithParameters(hostData, null, "/caldav", false, null).toString();
+                return OnboardingUtility.constructURLWithParameters(hostData, null, "/caldav", null).toString();
             }
             throw OnboardingExceptionCodes.MISSING_PROPERTY.create(propertyName);
         }
